@@ -17,15 +17,27 @@
  beerli@fsu.edu
  
  
-    Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
+Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-    This software is distributed free of charge for non-commercial use
- and is copyrighted. Of course, we do not guarantee that the software
- works and are not responsible for any damage you may cause or have.
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
+of the Software, and to permit persons to whom the Software is furnished to do
+so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all copies
+or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
+INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
+PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
+OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  
- 
-$Id: combroyden2.c 2035 2012-05-16 20:03:33Z beerli $
+$Id: combroyden2.c 2067 2012-07-27 20:59:32Z beerli $
  
 -------------------------------------------------------*/
 
@@ -203,7 +215,7 @@ estimateParameter (long rep, long G, world_fmt * world, option_fmt * options,
                                   world->loci);
     }
 
-    create_nr (nr, world, G, 0, world->locus, repkind, rep);
+    create_nr (nr, world, G, 0L, world->locus, repkind, rep);
     set_replicates (world, world->repkind, world->rep, &nr->repstart,
                     &nr->repstop);
     //    fprintf(stdout,"%i> DEBUG sumfile: world-rep=%li world->repkind=%li nr->repstart=%li nr->repstop=%li\n",myID, world->rep, world->repkind, nr->repstart, nr->repstop);
@@ -474,7 +486,7 @@ combine_gradient (nr_fmt * nr, helper_fmt * helper, MYREAL *gxv)
 #endif /*MPI*/
 
     }
-    force_symmetric_d (gxv, nr->world->options->migration_model, nr, nnn);
+    force_symmetric_d (gxv, (long) nr->world->options->migration_model, nr, nnn);
     grad2loggrad (helper->expxv, nr->indeks, gxv, nnn, nr->profilenum);
 }
 
@@ -1423,7 +1435,7 @@ maximize (MYREAL **thisparam, world_fmt * world, nr_fmt * nr, MYREAL **hess, lon
      //       lamda = golden_section (psilo, &helper, tempparam, templparam);
                 //line_search (dv, gxv, psilo, &helper, oldL, tempparam, templparam);
         helper.lamda = lamda = 1.;
-        while ((newL < oldL || MYISNAN ((float) newL) || newL <= -numbermax) &&
+        while ((newL < oldL || MYISNAN (newL) || newL <= -numbermax) &&
                 fabs (lamda) > 10. * eps)
         {
             calc_loci_param (nr, xv, xv0, dv, lamda, nn);
