@@ -33,12 +33,12 @@ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTIO
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE 
 OR THE USE OR OTHER DEALINGS IN THE SOFTWARE. 
 
-$Id: definitions.h 2071 2012-08-08 21:36:48Z beerli $
+$Id: definitions.h 2105 2012-11-28 16:21:38Z beerli $
  
 *----------------------------------------------------------------
 */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "3.3.1"
+#define MIGRATEVERSION "3.4.1"
 #endif
 #ifndef MIGRATESUBVERSION
 #define MIGRATESUBVERSION "x"
@@ -111,7 +111,9 @@ $Id: definitions.h 2071 2012-08-08 21:36:48Z beerli $
     #define DOS
     #undef HAVE_STRINGS_H
     #undef HAVE_LGAMMA
-    #define HAVE_STRFTIME
+    #ifndef HAVE_STRFTIME
+       #define HAVE_STRFTIME
+    #endif
     #undef HAVE_STRSEP
     #include "windows_timveval.h"
 #endif
@@ -589,4 +591,32 @@ long chains is used */
 #define MYINLINE /*inline*/
 #undef PRETTY
 #define PRETTY
+
+
+//show system info
+#ifdef MYSYSTEM
+#undef MYSYSTEM
+#endif
+#ifdef _AIX
+#define MYSYSTEM "IBM AIX"
+#endif
+#ifdef __bg__
+#define MYSYSTEM "IBM Blue Gene"
+#endif
+#ifdef __FreeBSD__
+#define MYSYSTEM "FreeBSD"
+#endif
+#ifdef __linux__
+#define MYSYSTEM "LINUX"
+#endif
+#ifdef __APPLE__
+#define MYSYSTEM "Macintosh"
+#endif
+#ifdef __WIN32__
+#define MYSYSTEM "Windows"
+#endif
+#ifndef MYSYSTEM
+#define MYSYSTEM "Other"
+#endif
+
 #endif /*definitions */
