@@ -16,7 +16,7 @@
  
   Copyright 2002 Peter Beerli and Joseph Felsenstein, Seattle WA
   Copyright 2003 Peter Beerli, Tallahassee FL
-  $Id: migration.h 2071 2012-08-08 21:36:48Z beerli $
+  $Id: migration.h 2100 2012-11-19 21:41:03Z beerli $
   *----------------------------------------------------------------
 */
 /**
@@ -293,7 +293,7 @@ typedef struct _bayeshistogram
 {
     long binsum; //sum of all elements of all parameters and bins
     long *bins;        // number of bins for each parameter
-    MYREAL *results;   // contains histogram, size is bins*numparam
+    float *results;   // contains histogram, size is bins*numparam
     char *set95; // holds in/out HPD set for 95% probability
     char *set50; // holds in/out HPD set for 50% probability [this is attached to cred95]
     // on a per parameter basis
@@ -605,6 +605,7 @@ typedef struct _option
   long mutationrate_year_numalloc; // 
   MYREAL generation_year;
   long randomsubset;
+  long randomsubsetseed;
 #ifdef SEASON
   MYREAL *timings; // vector of time points (options)
   long numtimings; // number of elements in the timings vector
@@ -613,6 +614,7 @@ typedef struct _option
   boolean heatedswap_off;
   boolean has_autotune;
   MYREAL autotune;
+  long totalsites; //for snp data
 }
 option_fmt;
 
