@@ -22,9 +22,10 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: random.c 2071 2012-08-08 21:36:48Z beerli $
+$Id: random.c 2104 2012-11-28 16:18:01Z beerli $
 -------------------------------------------------------*/
 /* \file random.c */
+#include <stdlib.h>
 #include "sighandler.h"
 #include "migration.h"
 #include "heating.h"
@@ -429,7 +430,9 @@ MYINLINE long random_integer(long low, long high)
 /// http://sourceware.org/ml/gsl-discuss/2004-q1/msg00071.html
 /// March 30, 2007, Robert G. Brown (http://www.phy.duke.edu/~rgb/)
 /// at Duke University Dept. of Physics, Box 90305  Durham, N.C. 27708-030
-/// suggested the code 
+/// suggested the code
+/// changed December 2012 because on som cluster machines little entropy
+/// is generated thus the machine stalls (AMD?) 
 unsigned long int random_seed()
 {
   
@@ -437,7 +440,7 @@ unsigned long int random_seed()
   struct timeval tv;
   FILE *devrandom;
   size_t retval;
-  if ((devrandom = fopen("/dev/random","r")) == NULL) 
+  if ((devrandom = fopen("/dev/urandom","r")) == NULL) 
     {
       gettimeofday(&tv,0);
       seed = tv.tv_sec + tv.tv_usec;
@@ -446,6 +449,11 @@ unsigned long int random_seed()
     {
       retval = fread(&seed,sizeof(seed),1,devrandom);
       fclose(devrandom);
+      if(seed == 0)
+	{
+	  gettimeofday(&tv,0);
+	  seed = tv.tv_sec + tv.tv_usec;
+	}
     }
   return(seed);
 }
@@ -513,8 +521,15 @@ void getseed_mt (option_fmt *options)
     set_seed(options->autoseed, &options->inseed);
     options->saveseed = options->inseed;
     init_gen_rand((unsigned long)options->inseed);
+    if(options->randomsubset>0 && options->randomsubsetseed > 0)
+      {
+#ifdef WIN32
+	srand(options->randomsubsetseed);
+#else
+	srand48(options->randomsubsetseed);
+#endif
+      }
 }
-
 ///
 /// set up the quasi random number material
 /// this function is dependent on running the standard MT or LCG random number generator first.
