@@ -16,7 +16,7 @@ Copyright 2003-2012 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: reporter.c 2071 2012-08-08 21:36:48Z beerli $
+$Id: reporter.c 2095 2012-10-25 21:40:10Z beerli $
  
 -------------------------------------------------------*/
 /* \file reporter.c 
@@ -334,8 +334,8 @@ void collect_ess_values(world_fmt *world)
       // summing ess values
       world->ess_archive[i] += world->effective_sample[i];
     }
-  //  n++;
-  //printf("%i> %li autoarchive %f autocorr %f n=%li\n", myID, world->rep,  world->auto_archive[0], world->autocorrelation[0], nn);
+  n++;
+  printf("%i> %li autoarchive %f autocorr %f n=%li\n", myID, world->rep,  world->auto_archive[0], world->autocorrelation[0], nn);
 }
 
 
