@@ -6,7 +6,7 @@
  Unique event polymorphism   R O U T I N E S
  
  Peter Beerli 2000, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
 Copyright 2002 Peter Beerli and Joseph Felsenstein
  
@@ -14,7 +14,7 @@ Copyright 2002 Peter Beerli and Joseph Felsenstein
         and is copyrighted. Of course, we do not guarantee that the software
         works and are not responsible for any damage you may cause or have.
  
-$Id: uep.c 886 2007-08-18 03:09:50Z beerli $
+$Id: uep.c 1323 2008-07-25 19:13:48Z beerli $
 */
 /* \file uep.c 
 Unique event polymorphism manipulation
